@@ -12,6 +12,7 @@ class Statistics:
         optionally populated by the ALNS algorithm.
         """
         self._objectives = []
+        self._runtimes = []
 
         self._destroy_operator_counts = defaultdict(lambda: [0, 0, 0, 0])
         self._repair_operator_counts = defaultdict(lambda: [0, 0, 0, 0])
@@ -23,6 +24,13 @@ class Statistics:
         """
         return np.array(self._objectives)
 
+    @property
+    def runtimes(self) -> np.ndarray:
+        """
+        Returns an array of iteration run times (in seconds).
+        """
+        return np.diff(self._runtimes, prepend=self._runtimes[0])
+
     @property
     def destroy_operator_counts(self) -> DefaultDict[str, List[float]]:
         """
@@ -62,6 +70,17 @@ class Statistics:
         """
         self._objectives.append(objective)
 
+    def collect_runtime(self, time: float):
+        """
+        Collects the time one iteration took.
+
+        Parameters
+        ----------
+        time
+            Time in seconds.
+        """
+        self._runtimes.append(time)
+
     def collect_destroy_operator(self, operator_name: str, s_idx: int):
         """
         Collects a score (index) for a used destroy operator. This maintains
